import { axisLeft,
        axisBottom,
        select,
        csv,
        extent,
        format,
        scaleLinear         
        } from 'd3';

const svg = select('svg');
const div = select("body").append("div").attr("class", "tooltip");

  	// d.mpg = +d.mpg;
  	// d.cylinders = +d.cylinders;
  	// d.displacement = +d.displacement;
  	// d.horsepower = +d.horsepower;
  	// d.weight = +d.weight;
  	// d.acceleration = +d.acceleration;
  	// d.year = +d.year;

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = "Cars: Horsepower vs Weight";
  const yValue = d => d.weight
  const yAxisLabel = "Weight";
  const xValue = d => d.horsepower
  const xAxisLabel = "Horsepower";
  const circleRadius = 12;
  
  const margin = {top:40,right:40, bottom:75, left:120}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0,innerHeight])
  .nice();
  	
  
  const g = svg.append("g")
  	.attr("transform", "translate("+margin.left+","+margin.top+")")
    
  const xAxis =axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(20);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  
  const yAxisG = g.append("g").call(yAxis)
  yAxisG.selectAll(".domain").remove();
  
  yAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr("y", -80)
  	.attr("x", -innerHeight/2)
  	.attr("fill","black")
    .attr("transform", "rotate(-90)")
  	.attr("text-anchor", "middle")
  	.text(yAxisLabel);
  
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", "translate(0,"+innerHeight+")")
  
  xAxisG.select(".domain").remove();
  
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr("y", 65)
  	.attr("x", innerWidth/2)
  	.attr("fill","black")
  	.text(xAxisLabel);
  
  g.selectAll("circle").data(data)
  	.enter().append("circle")
  		.attr("cy", d => yScale(yValue(d)))
  		.attr("cx", d => xScale(xValue(d)))
  		.attr("r", circleRadius)
  		.on("mouseover", function(d){
    		console.log(event.pageY)
    		div.style("opacity",0.8)
    		div.style("top", event.pageY+"px")
    		div.style("left", event.pageX+"px")
    		div.text(d.population)  		
  		})
  		.on("mouseout", function(d){
  			div.style("opacity",0)
  		})
  
  g.append("text")
  	.attr("y", -10)
  	.attr("class", "title")
    .text(title);
   
}  

csv("https://vizhub.com/curran/datasets/auto-mpg.csv")
  .then(data=>{
  	data.forEach(d=>{
  	d.mpg = +d.mpg;
  	d.cylinders = +d.cylinders;
  	d.displacement = +d.displacement;
  	d.horsepower = +d.horsepower;
  	d.weight = +d.weight;
  	d.acceleration = +d.acceleration;
  	d.year = +d.year;
    
  })
    render(data)
})